@@ -378,8 +378,8 @@ class CycleComponent(Base):
     name_kz = Column('cycle_component_name_kz', String)
     name_en = Column('cycle_component_name_en', String)
     short_name_ru = Column('cycle_component_short_name_ru', String)
-    short_name_kz = Column('cycle_component_short_name_ru', String)
-    short_name_en = Column('cycle_component_short_name_ru', String)
+    short_name_kz = Column('cycle_component_short_name_kz', String)
+    short_name_en = Column('cycle_component_short_name_en', String)
 
     def __repr__(self):
         return f'<CycleComponent {self} (id={self.id} status={self.status})>'
